﻿* Encoding: UTF-8.
/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIÓN DE LA EDUCACIÓN
/*             UNIDAD DE EVALUACIÓN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIÓN GENERAL DE MEDICIÓN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIÓN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*                  EVOE-Evaluación de la Implementación Curricular (EIC)
/*                                  PREESCOLAR
/*
/*  *** Cuestionario para la Docente y el Responsable de preescolar (LEC) ***
/*
/*_____________________________________________________________________________
/*
/*
/*            SINTAXIS PARA ETIQUETAR LA TABLA DE DATOS DE DOCENTES Y LEC
/*                       EN FORMATO SPSS PARA EIC-00, 2017
/*_____________________________________________________________________________
/*
/*  La sintaxis etiqueta las variables así como sus valores y declara los
/*  valores perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para etiquetar la base de datos (tabla de datos) es necesario:
/*      1) Abrir la tabla de en formato SPSS y el archivo de sintaxis
/*      2) Ejecutar toda la sintaxis del archivo.
/*
/*  Al finalizar el ejecución del sintaxis, la tabla EIC00_2017_Docentes_LEC.SAV
/*  quedará etiquetada.
/*
/* CONTACTO:
/*
/*      Para mayor información o aclaración de dudas favor de contactar a la
/*      Dirección de Tratamiento de Datos
/*      Correo electrónico: analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San José Insurgentes
/*                 Del. Benito Juárez. Ciudad de México
/*
/* FECHA DE LIBERACIÓN:  XX DE XXXXXX 2018
/*
/*  ****************************************************************************/

/***********************************************************************
/*       Etiquetas de variables
/*
/**********************************************************************.

VARIABLE LABELS
       NACIONAL        "Variable auxiliar para obtener promedios nacionales"
       FOLIO           "Folio"
       ESCUELA         "Identificador de la escuela"
       ID_ENT          "Entidad federativa (identificador numérico)"
       NOM_ENT         "Entidad federativa"
       ID_PREESTRATO   "Identificador numérico del Dominio de interés"
       PREESTRATO      "Dominio de interés"
       FUENTE          "Base de datos origen, Docente o LEC"
       RPEA            "Índice de acuerdo con los retos en la evaluación de aprendizajes"
       RPEANVL         "Nivel de acuerdo con los retos en la evaluación de aprendizajes"
       DPE             "Índice de acuerdo con las dificultades de la planeación escrita"
       DPENVL          "Nivel de acuerdo con las dificultades de la planeación escrita"
       W_FGRPWT        "Peso final muestral del docente en General, Indígena, Privada o del LEC"
       M01             "Usted es:"
       L02             "¿Qué edad tiene?"
       M02             "¿Qué edad tiene?"
       M03             "De acuerdo con su cultura, ¿usted se considera indígena?"
       M04             "¿Usted habla algún dialecto o lengua indígena?"
       M05             "¿En su grupo tiene niñas o niños que hablan algún dialecto o lengua indígena?"
       M06a            "¿Qué tanto domina la variante de lengua indígena que habla la mayoría de niñas y niños de su grupo? Entiendo"
       M06b            "¿Qué tanto domina la variante de lengua indígena que habla la mayoría de niñas y niños de su grupo? Hablo"
       M06c            "¿Qué tanto domina la variante de lengua indígena que habla la mayoría de niñas y niños de su grupo? Leo"
       M06d            "¿Qué tanto domina la variante de lengua indígena que habla la mayoría de niñas y niños de su grupo? Escribo"
       M07             "De acuerdo con su cultura, historia y tradiciones, ¿usted se considera negra, es decir, afromexicana o afrodescendiente? (Se incluye el término “negra” debido a que una parte de la población afrodescendiente se reconoce de esa manera)."
       M08             "¿Cuántos años de experiencia tiene como docente de preescolar?"
       M09             "¿Cuántos años tiene laborando como docente en este centro escolar?"
       M10             "Señale el nivel máximo de estudios del que tiene certificado, título o cédula profesional."
       M11             "¿En qué área de conocimiento se ubica su nivel máximo de estudios del que tiene certificado, título o cédula profesional?"
       M12a            "En este centro escolar y turno, ¿tiene alumnos de cada grado en su grupo? Primer grado"
       M12b            "En este centro escolar y turno, ¿tiene alumnos de cada grado en su grupo? Segundo grado"
       M12c            "En este centro escolar y turno, ¿tiene alumnos de cada grado en su grupo? Tercer grado"
       M13a            "Actualmente, ¿cuántas niñas y niños de preescolar tiene en su grupo? Escriba la cantidad con número. Niñas"
       M13b            "Actualmente, ¿cuántas niñas y niños de preescolar tiene en su grupo? Escriba la cantidad con número. Niños"
       L14a            "En el centro escolar en el que trabaja, además de preescolar, ¿atiende otro nivel educativo? Primaria"
       L14b            "En el centro escolar en el que trabaja, además de preescolar, ¿atiende otro nivel educativo? Secundaria"
       M14a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Es necesario que niñas y niños inicien el preescolar desde los 3 años de edad para que al concluirlo logren: usar un objeto o herramienta ade... (ver cuestionario .pdf)"
       M14b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Es necesario que niñas y niños inicien el preescolar desde los 3 años de edad para que al concluirlo logren: participar en juegos que implican... (ver cuestionario .pdf)"
       M14c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Es necesario que niñas y niños inicien el preescolar desde los 3 años de edad para que al concluirlo logren: controlar conductas impulsivas que... (ver cuestionario .pdf)"
       M14d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Es necesario que niñas y niños inicien el preescolar desde los 3 años de edad para que al concluirlo logren: mostrar interés, emoción y moti... (ver cuestionario .pdf)"
       M14e            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Es necesario que niñas y niños inicien el preescolar desde los 3 años de edad para que al concluirlo logren: saludar, despedirse, pedir las co... (ver cuestionario .pdf)"
       M14f            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Es necesario que niñas y niños inicien el preescolar desde los 3 años de edad para que al concluirlo logren: lavarse las manos y los dientes... (ver cuestionario .pdf)"
       M14g            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Es necesario que niñas y niños inicien el preescolar desde los 3 años de edad para que al concluirlo logren: elaborar explicaciones propias... (ver cuestionario .pdf)"
       M14h            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Es necesario que niñas y niños inicien el preescolar desde los 3 años de edad para que al concluirlo logren: utilizar marcas gráficas (sig... (ver cuestionario .pdf)"
       M15a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Creo que un programa de estudios debe: definir todos los aprendizajes que se enseñarán en cada grupo"
       M15b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Creo que un programa de estudios debe: permitir que la educadora defina el orden de los aprendizajes a desarrollar en cada grado"
       M15c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Creo que un programa de estudios debe: permitir que la educadora diseñe las situaciones didácticas"
       M15d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Creo que un programa de estudios debe: establecer el tiempo en el que debe desarrollarse cada una de las situaciones didácticas"
       M16a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para implementar un programa de estudios, considero que los principales apoyos que necesito son: explicaciones de los enfoques didácticos... (ver cuestionario .pdf)"
       M16b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para implementar un programa de estudios, considero que los principales apoyos que necesito son: explicaciones sobre los procesos de des... (ver cuestionario .pdf)"
       M16c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para implementar un programa de estudios, considero que los principales apoyos que necesito son: estrategias de enseñanza y aprendizaje... (ver cuestionario .pdf)"
       M16d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para implementar un programa de estudios, considero que los principales apoyos que necesito son: estrategias para el trabajo con niñas y niños... (ver cuestionario .pdf)"
       M16e            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para implementar un programa de estudios, considero que los principales apoyos que necesito son: estrategias para evaluar los avances... (ver cuestionario .pdf)"
       M16f            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para implementar un programa de estudios, considero que los principales apoyos que necesito son: materiales de apoyo didáctico (por ejemplo: libros... (ver cuestionario .pdf)"
       M16g            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para implementar un programa de estudios, considero que los principales apoyos que necesito son: recursos para la elaboración de mis propios ... (ver cuestionario .pdf)"
       M17a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para elaborar la planeación de la jornada escolar por escrito, lo más complicado es: diseñar diferentes formas de trabajo en el grupo para cada clase"
       M17b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para elaborar la planeación de la jornada escolar por escrito, lo más complicado es: relacionar los aprendizajes de diversos campos formativos"
       M17c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para elaborar la planeación de la jornada escolar por escrito, lo más complicado es: diseñar actividades adecuadas a lo que desean aprender niñas y niños"
       M17d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para elaborar la planeación de la jornada escolar por escrito, lo más complicado es: diseñar actividades adecuadas a las características y los... (ver cuestionario .pdf)"
       M17e            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para elaborar la planeación de la jornada escolar por escrito, lo más complicado es: diseñar actividades que involucren el contexto de la com... (ver cuestionario .pdf)"
       M17f            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para elaborar la planeación de la jornada escolar por escrito, lo más complicado es: diseñar las estrategias para evaluar los aprendizajes"
       L18f            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones? Para elaborar la planeación de la jornada escolar por escrito, lo más complicado es: organizar la tutoría dentro del grupo"
       M18a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para mantener el orden y la disciplina en mi grupo es necesario: que niñas y niños establezcan las normas de convivencia junto conmigo"
       M18b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para mantener el orden y la disciplina en mi grupo es necesario: tomar en cuenta la opinión de niñas y niños acerca de las actividades de aprendizaje que prefieren"
       M18c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para mantener el orden y la disciplina en mi grupo es necesario: que yo ponga todas las normas de convivencia"
       M18d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para mantener el orden y la disciplina en mi grupo es necesario: que yo siempre decida cómo deben trabajar niñas y niños (por ejemplo: con... (ver cuestionario .pdf)"
       M19a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Cuando dos niñas o niños se están peleando, por ejemplo, por el uso del material en una actividad, lo mejor es: separarlos, llamarles la atención... (ver cuestionario .pdf)"
       M19b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Cuando dos niñas o niños se están peleando, por ejemplo, por el uso del material en una actividad, lo mejor es: intervenir en la situación y buscar que lleguen a un acuerdo"
       M19c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Cuando dos niñas o niños se están peleando, por ejemplo, por el uso del material en una actividad, lo mejor es: sancionar a quien comenzó la agresión"
       M20a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para conformar equipos de trabajo en el aula es mejor agrupar a: niñas y niños con necesidades de aprendizaje similares"
       M20b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para conformar equipos de trabajo en el aula es mejor agrupar a: niñas y niños con ritmos de aprendizaje similares"
       M20c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para conformar equipos de trabajo en el aula es mejor agrupar a: niñas y niños con niveles de logro similares"
       M20d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para conformar equipos de trabajo en el aula es mejor agrupar a: niñas con niñas y niños con niños"
       M21a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para evaluar el aprendizaje de niñas y niños, lo más complicado es observar los avances en: el control de su cuerpo en diferentes movimientos y ... (ver cuestionario .pdf)"
       M21b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para evaluar el aprendizaje de niñas y niños, lo más complicado es observar los avances en: la combinación de movimientos complejos (por ejemplo:... (ver cuestionario .pdf)"
       M21c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para evaluar el aprendizaje de niñas y niños, lo más complicado es observar los avances en: la interacción con otras niñas y niños con... (ver cuestionario .pdf)"
       M21d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para evaluar el aprendizaje de niñas y niños, lo más complicado es observar los avances en: la expresión de sensaciones y sentimientos sobre per... (ver cuestionario .pdf)"
       M21e            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para evaluar el aprendizaje de niñas y niños, lo más complicado es observar los avances en: los hábitos de orden (por ejemplo: esperar su turno y acomodar los materiales)"
       M21f            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para evaluar el aprendizaje de niñas y niños, lo más complicado es observar los avances en: los hábitos de higiene (por ejemplo: limpiar... (ver cuestionario .pdf)"
       M21g            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para evaluar el aprendizaje de niñas y niños, lo más complicado es observar los avances en: la resolución de problemas numéricos y su repre... (ver cuestionario .pdf)"
       M21h            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Para evaluar el aprendizaje de niñas y niños, lo más complicado es observar los avances en: la descripción de personas, objetos, lugares y fenóme... (ver cuestionario .pdf)"
       M22a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En la evaluación de los aprendizajes de niñas y niños, lo más difícil es: identificar sus características y ritmos de aprendizaje"
       M22b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En la evaluación de los aprendizajes de niñas y niños, lo más difícil es: distinguir entre avances y logros en sus aprendizajes"
       M22c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En la evaluación de los aprendizajes de niñas y niños, lo más difícil es: reconocer los momentos en que debo observar y registrar sus aprendizajes"
       M22d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En la evaluación de los aprendizajes de niñas y niños, lo más difícil es: seleccionar los instrumentos que me permiten registrar sus aprendizajes"
       M22e            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En la evaluación de los aprendizajes de niñas y niños, lo más difícil es: usar lo que registré para ayudar a que niñas y niños mejoren"
       M22f            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En la evaluación de los aprendizajes de niñas y niños, lo más difícil es: aprovechar lo que registré para mejorar mi práctica"
       M22g            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En la evaluación de los aprendizajes de niñas y niños, lo más difícil es: informar a los padres de familia lo que sus hijos e hijas han aprendido"
       M23a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que las niñas (mujeres) tienen mayor facilidad para… hacer actividades físicas (por ejemplo: correr o brincar)"
       M23b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que las niñas (mujeres) tienen mayor facilidad para… hacer actividades manuales (por ejemplo: recortar o dibujar)"
       M23c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que las niñas (mujeres) tienen mayor facilidad para… regular sus emociones y conductas"
       M23d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que las niñas (mujeres) tienen mayor facilidad para… relacionarse adecuadamente con otras personas"
       M23e            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que las niñas (mujeres) tienen mayor facilidad para… adquirir hábitos de orden y cortesía (por ejemplo: esperar su turno y dar las gracias)"
       M23f            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que las niñas (mujeres) tienen mayor facilidad para… adquirir hábitos de higiene y cuidado personal (por ejemplo: tirar la... (ver cuestionario .pdf)"
       M23g            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que las niñas (mujeres) tienen mayor facilidad para… resolver problemas de pensamiento matemático"
       M23h            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que las niñas (mujeres) tienen mayor facilidad para… expresarse con fluidez en el lenguaje oral o escrito"
       M24a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que los niños (hombres) tienen mayor facilidad para… hacer actividades físicas (por ejemplo: correr o brincar)"
       M24b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que los niños (hombres) tienen mayor facilidad para… hacer actividades manuales (por ejemplo: recortar o dibujar)"
       M24c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que los niños (hombres) tienen mayor facilidad para… regular sus emociones y conductas"
       M24d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que los niños (hombres) tienen mayor facilidad para… relacionarse adecuadamente con otras personas"
       M24e            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que los niños (hombres) tienen mayor facilidad para… adquirir hábitos de orden y cortesía (por ejemplo: esperar su turno y dar las gracias)"
       M24f            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que los niños (hombres) tienen mayor facilidad para… adquirir hábitos de higiene y cuidado personal (por ejemplo: tirar la... (ver cuestionario .pdf)"
       M24g            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que los niños (hombres) tienen mayor facilidad para… resolver problemas de pensamiento matemático"
       M24h            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. En general, considero que los niños (hombres) tienen mayor facilidad para… expresarse con fluidez en el lenguaje oral o escrito"
       M25a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Yo creo que niñas y niños que sólo hablan algún dialecto o lengua indígena deben aprender: sólo en español"
       M25b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Yo creo que niñas y niños que sólo hablan algún dialecto o lengua indígena deben aprender: sólo en su dialecto o lengua indígena"
       M25c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Yo creo que niñas y niños que sólo hablan algún dialecto o lengua indígena deben aprender: en español y en su dialecto o lengua indígena"
       M26a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Por las reuniones que he tenido con los padres de familia, yo creo que lo más importante para ellos es que sus hijos desarrollen: habilidades para... (ver cuestionario .pdf)"
       M26b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Por las reuniones que he tenido con los padres de familia, yo creo que lo más importante para ellos es que sus hijos desarrollen: la capacidad de... (ver cuestionario .pdf)"
       M26c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Por las reuniones que he tenido con los padres de familia, yo creo que lo más importante para ellos es que sus hijos desarrollen: hábitos de orden,... (ver cuestionario .pdf)"
       M26d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Por las reuniones que he tenido con los padres de familia, yo creo que lo más importante para ellos es que sus hijos desarrollen: la capacidad de... (ver cuestionario .pdf)"
       M27a            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Considero que el aprendizaje de niñas y niños se dificulta, principalmente, cuando los padres de familia: viven separados"
       M27b            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Considero que el aprendizaje de niñas y niños se dificulta, principalmente, cuando los padres de familia: tienen pocos estudios"
       M27c            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Considero que el aprendizaje de niñas y niños se dificulta, principalmente, cuando los padres de familia: tienen pocos recursos económicos"
       M27d            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Considero que el aprendizaje de niñas y niños se dificulta, principalmente, cuando los padres de familia: asisten poco a los eventos escolares... (ver cuestionario .pdf)"
       M27e            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Considero que el aprendizaje de niñas y niños se dificulta, principalmente, cuando los padres de familia: se involucran poco en las actividades... (ver cuestionario .pdf)"
       M27f            "¿Qué tan de acuerdo o en desacuerdo está con las siguientes afirmaciones?. Considero que el aprendizaje de niñas y niños se dificulta, principalmente, cuando los padres de familia: solicitan poca información acerca del... (ver cuestionario .pdf)"
       WVARSTRR        "Identificador del pseudoestrato (1 a 100) definido para el cálculo de errores estándar con el método de remuestreo BRR"
       W_FGRR1         "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR2         "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR3         "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR4         "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR5         "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR6         "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR7         "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR8         "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR9         "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR10        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR11        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR12        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR13        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR14        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR15        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR16        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR17        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR18        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR19        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR20        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR21        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR22        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR23        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR24        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR25        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR26        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR27        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR28        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR29        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR30        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR31        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR32        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR33        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR34        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR35        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR36        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR37        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR38        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR39        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR40        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR41        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR42        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR43        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR44        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR45        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR46        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR47        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR48        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR49        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR50        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR51        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR52        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR53        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR54        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR55        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR56        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR57        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR58        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR59        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR60        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR61        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR62        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR63        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR64        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR65        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR66        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR67        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR68        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR69        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR70        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR71        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR72        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR73        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR74        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR75        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR76        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR77        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR78        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR79        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR80        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR81        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR82        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR83        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR84        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR85        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR86        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR87        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR88        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR89        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR90        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR91        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR92        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR93        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR94        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR95        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR96        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR97        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR98        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR99        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FGRR100       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       VERSION         "Versión de la base de datos"
.



/***********************************************************************
/*       Etiquetas de valores.
/*
/**********************************************************************.


VALUE LABELS
    ID_ENT
             1       "Aguascalientes"
             2       "Baja California"
             3       "Baja California Sur"
             4       "Campeche"
             5       "Coahuila"
             6       "Colima"
             7       "Chiapas"
             8       "Chihuahua"
             9       "Ciudad de México"
             10      "Durango"
             11      "Guanajuato"
             12      "Guerrero"
             13      "Hidalgo"
             14      "Jalisco"
             15      "México"
             16      "Michoacán"
             17      "Morelos"
             18      "Nayarit"
             19      "Nuevo León"
             20      "Oaxaca"
             21      "Puebla"
             22      "Querétaro"
             23      "Quintana Roo"
             24      "San Luis Potosí"
             25      "Sinaloa"
             26      "Sonora"
             27      "Tabasco"
             28      "Tamaulipas"
             29      "Tlaxcala"
             30      "Veracruz"
             31      "Yucatán"
             32      "Zacatecas"/
    ID_PREESTRATO
             1       "Cursos Comunitarios"
             2       "Gral Unidocente"
             3       "Gral No Unidocente"
             4       "Indígena Unidocente"
             5       "Indígena No Unidocente"
             6       "Privadas"/
    RPEANVL  1       "Nivel 1"
             2       "Nivel 2"/
    DPENVL   1       "Nivel 1"
             2       "Nivel 2"/
    M01      1       "hombre"
             2       "mujer"
             98      "Respuesta Múltiple"
             99      "Respuesta Omitida"/
    L02
    M02      997     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
             999     "Respuesta Omitida"
             996     "Valor Inconsistente"/
    M03      1       "Sí"
             2       "Sí, en parte"
             3       "No"
             4       "No sé"
             98      "Respuesta Múltiple"
             99      "Respuesta Omitida"/
    M04      1       "Sí"
             2       "No"
             98      "Respuesta Múltiple"
             99      "Respuesta Omitida"/
    M05      1       "Sí"
             2       "No"
             98      "Respuesta Múltiple"
             99      "Respuesta Omitida"/
    M06a
    M06b
    M06c
    M06d     1       "Nada"
             2       "Poco"
             3       "Suficiente"
             4       "Totalmente"
             98      "Respuesta Múltiple"
             99      "Respuesta Omitida"
             93      "No aplica por pregunta filtro"
             96      "Valor Inconsistente"/
    M07      1       "Sí"
             2       "Sí, en parte"
             3       "No"
             4       "No sé"
             98      "Respuesta Múltiple"
             99      "Respuesta Omitida"/
    M08
    M09      999     "Respuesta Omitida"
             996     "Valor Inconsistente"/
    M10      1       "Secundaria"
             2       "Bachillerato (Técnico o Profes... (ver cuestionario .pdf)"
             3       "Normal básica sin licenciatura... (ver cuestionario .pdf)"
             4       "Normal superior (la que se estudiaba antes del año 2000)"
             5       "Técnico Superior Universitario"
             6       "Licenciatura (Escuela Normal,... (ver cuestionario .pdf)"
             7       "Especialidad"
             8       "Maestría"
             9       "Doctorado"
             98      "Respuesta Múltiple"
             99      "Respuesta Omitida"/
    M11      1       "Educación preescolar"
             2       "Educación de otro nivel educat... (ver cuestionario .pdf)"
             3       "Educación especial"
             4       "Educación en general, pedagogí... (ver cuestionario .pdf)"
             5       "En un área no relacionada con la educación"
             98      "Respuesta Múltiple"
             99      "Respuesta Omitida"
             93      "No aplica por pregunta filtro"
             96      "Valor Inconsistente"/
    M12a
    M12b
    M12c     1       "Sí"
             2       "No"
             98      "Respuesta Múltiple"
             99      "Respuesta Omitida"
             96      "Valor Inconsistente"/
    M13a
    M13b     999     "Respuesta Omitida"
             996     "Valor Inconsistente"/
    L14a
    L14b     1       "Sí"
             2       "No"
             97      "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
             98      "Respuesta Múltiple"
             99      "Respuesta Omitida"/
    M14a
    M14b
    M14c
    M14d
    M14e
    M14f
    M14g
    M14h
    M15a
    M15b
    M15c
    M15d
    M16a
    M16b
    M16c
    M16d
    M16e
    M16f
    M16g
    M17a
    M17b
    M17c
    M17d
    M17e
    M17f
    L18f
    M18a
    M18b
    M18c
    M18d
    M19a
    M19b
    M19c
    M20a
    M20b
    M20c
    M20d
    M21a
    M21b
    M21c
    M21d
    M21e
    M21f
    M21g
    M21h
    M22a
    M22b
    M22c
    M22d
    M22e
    M22f
    M22g
    M23a
    M23b
    M23c
    M23d
    M23e
    M23f
    M23g
    M23h
    M24a
    M24b
    M24c
    M24d
    M24e
    M24f
    M24g
    M24h
    M25a
    M25b
    M25c
    M26a
    M26b
    M26c
    M26d
    M27a
    M27b
    M27c
    M27d
    M27e
    M27f
             0       "0"
             1       "1"
             2       "2"
             3       "3"
             4       "4"
             5       "5"
             6       "6"
             7       "7"
             8       "8"
             9       "9"
             10      "10"
             97      "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
             98      "Respuesta Múltiple"
             99      "Respuesta Omitida"/
.





/***********************************************************************
/*       Declaración de valores perdidos.
/*
/**********************************************************************.

MISSING VALUES M01 (98,99).
MISSING VALUES L02 TO M02 (996 TO 999).
MISSING VALUES M03 TO M05 (98,99).
MISSING VALUES M06a TO M06d (93 TO 99).
MISSING VALUES M07 (98,99).
MISSING VALUES M08 TO M09 (996 TO 999).
MISSING VALUES M10 (98,99).
MISSING VALUES M11 (93 TO 99).
MISSING VALUES M12a TO M12c (96 TO 99).
MISSING VALUES M13a TO M13b (996 TO 999).
MISSING VALUES L14a TO M27f (97 TO 99).


EXECUTE.
